%global pypi_name sympy
%global pypi_version 1.12.1

Summary:        Computer algebra system (CAS) in Python
Name:           python-%{pypi_name}
Version:        %{pypi_version}
Release:        1%{?dist}

License:        BSD-3-Clause AND MIT
URL:            https://www.sympy.org/en/index.html
Source0:        %{pypi_source %{pypi_name}}

# Fix incompatible pointers, which are an error with GCC 14
# base on https://github.com/sympy/sympy/pull/25968
# made modifications according to the latest code
Patch0001:         %{pypi_name}-incompatible-pointer-new.patch

# Skip tests that require a display
Patch3000:         %{pypi_name}-circuitplot.patch

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3-pip
BuildRequires:  python3-wheel
BuildRequires:  python3-setuptools

%description
SymPy is a Python library for symbolic mathematics. It aims to become a full-featured 
computer algebra system (CAS) while keeping the code as simple as possible in order to 
be comprehensible and easily extensible. SymPy is written entirely in Python. 
See more at https://github.com/sympy/sympy/blob/master/README.md

%package -n     python3-%{pypi_name}
Summary:        %{summary}
Requires:       python3-mpmath >= 0.19
Requires:       python3 >= 3.8
Provides:       python3-%{pypi_name} = %{version}

%description -n python3-%{pypi_name}
SymPy is a Python library for symbolic mathematics. It aims to become a full-featured 
computer algebra system (CAS) while keeping the code as simple as possible in order to 
be comprehensible and easily extensible. SymPy is written entirely in Python. 
See more at https://github.com/sympy/sympy/blob/master/README.md


	
%package -n     python3-%{pypi_name}-examples
License:        BSD-3-Clause
Summary:        Sympy examples
Requires:       python3-%{pypi_name} = %{version}-%{release}
 
%description -n python3-%{pypi_name}-examples
This package contains example input for sympy.

%prep
%autosetup -p1 -n %{pypi_name}-%{pypi_version}
	
fixtimestamp() {
  touch -r $1.orig $1
  rm -f $1.orig
}
 
# Do not depend on env
for fil in $(grep -rl "^#\![[:blank:]]*%{_bindir}/env" .); do
  sed -i.orig 's,^\(#\![[:blank:]]*%{_bindir}/\)env python,\1python3,' $fil
  fixtimestamp $fil
done
 
# Remove bogus shebangs
for fil in sympy/physics/mechanics/models.py \
           sympy/physics/optics/polarization.py; do
  sed -i.orig '/env python/d' $fil
  fixtimestamp $fil
done
 
# Use local objects.inv for intersphinx
sed -e "s|\('https://mpmath\.org/doc/current/', \)None|\1'%{_docdir}/python-mpmath-doc/html/objects.inv'|" \
    -i doc/src/conf.py


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files sympy isympy
	
## Remove extra files
rm -f %{buildroot}%{_bindir}/{,doc}test
 
# Don't let an executable script go into the documentation
chmod -R a-x+X examples
 
# Fix permissions
chmod 0755 %{buildroot}%{python3_sitelib}/sympy/benchmarks/bench_symbench.py \
      %{buildroot}%{python3_sitelib}/sympy/testing/tests/diagnose_imports.py

# Install the HTML documentation

# Try to get rid of pyc files, which aren't useful for documentation
find examples/ -name '*.py[co]' -print -delete

%check

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc AUTHORS README.md
%{_bindir}/isympy
%{_mandir}/man1/isympy.1*
 
%files -n python3-%{pypi_name}-examples
%doc examples/*
 

%changelog
* Tue Jun 25 2024 Clare <clarehkli@tencent.com> - 1.12.1-1
- [Type] other
- [DESC] initial build
